@@ -21,7 +21,7 @@ try:
 except ImportError:
     from urllib import request as http
     from urllib.parse import urljoin, urlparse
-from ._utils import log
+from .utils import log
 
 
 __all__ = ('OAuth', 'OAuthRemoteApp', 'OAuthResponse', 'OAuthException')
@@ -116,8 +116,7 @@ def parse_response(resp, content, strict=False, content_type=None):
         return json.loads(content)
 
     if ct in ('application/xml', 'text/xml'):
-        charset = options.get('charset', 'utf-8')
-        return get_etree().fromstring(content.decode(charset))
+        return get_etree().fromstring(content)
 
     if ct != 'application/x-www-form-urlencoded' and strict:
         return content
@@ -261,7 +260,6 @@ class OAuthRemoteApp(object):
                 'OAuthRemoteApp requires consumer key and secret'
             )
 
-
         self._base_url = base_url
         self._request_token_url = request_token_url
         self._access_token_url = access_token_url
@@ -305,11 +303,11 @@ class OAuthRemoteApp(object):
 
     @cached_property
     def request_token_params(self):
-        return self._get_property('request_token_params', None)
+        return self._get_property('request_token_params', {})
 
     @cached_property
     def access_token_params(self):
-        return self._get_property('access_token_params', None)
+        return self._get_property('access_token_params', {})
 
     @cached_property
     def access_token_method(self):
@@ -324,6 +322,8 @@ class OAuthRemoteApp(object):
         if attr:
             return attr
         if default is not False and not self.app_key:
+            # since it has no app_key, use the original property
+            # YES, it is `attr`, not default
             return attr
         app = self.oauth.app or current_app
         config = app.config[self.app_key]
@@ -338,7 +338,7 @@ class OAuthRemoteApp(object):
                 self.consumer_key, self.consumer_secret
             )
 
-            params = self.request_token_params
+            params = self.request_token_params or {}
             if 'signature_method' in params:
                 client.signature_method = _encode(params['signature_method'])
             if 'rsa_key' in params:
@@ -454,7 +454,7 @@ class OAuthRemoteApp(object):
         else:
             assert callback is not None, 'Callback is required OAuth2'
 
-            params = dict(self.request_token_params)
+            params = self.request_token_params or {}
             client = self.make_client()
 
             scope = params.pop('scope')
